@@ -13,10 +13,9 @@
 # limitations under the License.
 
 import mock
-import pytest
 from six.moves import http_client
 
-from google.resumable_media.requests import _helpers
+from google.resumable_media.requests import _request_helpers
 
 EXPECTED_TIMEOUT = (61, 60)
 
@@ -25,17 +24,17 @@ class TestRequestsMixin(object):
     def test__get_status_code(self):
         status_code = int(http_client.OK)
         response = _make_response(status_code)
-        assert status_code == _helpers.RequestsMixin._get_status_code(response)
+        assert status_code == _request_helpers.RequestsMixin._get_status_code(response)
 
     def test__get_headers(self):
         headers = {u"fruit": u"apple"}
         response = mock.Mock(headers=headers, spec=["headers"])
-        assert headers == _helpers.RequestsMixin._get_headers(response)
+        assert headers == _request_helpers.RequestsMixin._get_headers(response)
 
     def test__get_body(self):
         body = b"This is the payload."
         response = mock.Mock(content=body, spec=["content"])
-        assert body == _helpers.RequestsMixin._get_body(response)
+        assert body == _request_helpers.RequestsMixin._get_body(response)
 
 
 class TestRawRequestsMixin(object):
@@ -44,15 +43,15 @@ class TestRawRequestsMixin(object):
         raw = mock.Mock(spec=["stream"])
         raw.stream.return_value = iter([body])
         response = mock.Mock(raw=raw, _content=False, spec=["raw", "_content"])
-        assert body == _helpers.RawRequestsMixin._get_body(response)
+        assert body == _request_helpers.RawRequestsMixin._get_body(response)
         raw.stream.assert_called_once_with(
-            _helpers._SINGLE_GET_CHUNK_SIZE, decode_content=False
+            _request_helpers._SINGLE_GET_CHUNK_SIZE, decode_content=False
         )
 
     def test__get_body_w_content_consumed(self):
         body = b"This is the payload."
         response = mock.Mock(_content=body, spec=["_content"])
-        assert body == _helpers.RawRequestsMixin._get_body(response)
+        assert body == _request_helpers.RawRequestsMixin._get_body(response)
 
 
 def test_http_request():
@@ -62,7 +61,7 @@ def test_http_request():
     data = mock.sentinel.data
     headers = {u"one": u"fish", u"blue": u"fish"}
     timeout = mock.sentinel.timeout
-    ret_val = _helpers.http_request(
+    ret_val = _request_helpers.http_request(
         transport,
         method,
         url,
@@ -89,7 +88,7 @@ def test_http_request_defaults():
     transport, responses = _make_transport(http_client.OK)
     method = u"POST"
     url = u"http://test.invalid"
-    ret_val = _helpers.http_request(transport, method, url)
+    ret_val = _request_helpers.http_request(transport, method, url)
 
     assert ret_val is responses[0]
     transport.request.assert_called_once_with(
@@ -97,49 +96,6 @@ def test_http_request_defaults():
     )
 
 
-def test_crc32c_throws_import_error():
-    try:
-        import builtins
-    except ImportError:
-        import __builtin__ as builtins
-    orig_import = builtins.__import__
-
-    # Raises ImportError for name == "crc32c" or name == "crcmod"
-    def mock_import(name, globals, locals, fromlist, level=None):
-        raise ImportError
-
-    builtins.__import__ = mock_import
-
-    try:
-        with pytest.raises(ImportError):
-            _helpers._get_crc32c_object()
-    finally:
-        builtins.__import__ = orig_import
-
-
-@pytest.mark.filterwarnings("ignore::RuntimeWarning")
-def test_crc32c_warning_on_slow_crcmod():
-    try:
-        import builtins
-    except ImportError:
-        import __builtin__ as builtins
-
-    orig_import = builtins.__import__
-
-    # crcmod.crcmod is the only import.
-    def mock_import(name, globals, locals, fromlist, level):
-        crcmod = mock.MagicMock()
-        crcmod._usingExtension = False
-        return crcmod
-
-    builtins.__import__ = mock_import
-
-    try:
-        assert not _helpers._is_fast_crcmod()
-    finally:
-        builtins.__import__ = orig_import
-
-
 def _make_response(status_code):
     return mock.Mock(status_code=status_code, spec=["status_code"])
 
